@@ -10,7 +10,7 @@ from .paths import pari_share
 
 def rebuild(force=False):
     pari_module_path = 'cypari2'
-    src_files = [join(pari_share(), b'pari.desc')] + \
+    src_files = [join(pari_share(), 'pari.desc')] + \
                  glob.glob(join('autogen', '*.py'))
     gen_files = [join(pari_module_path, 'auto_paridecl.pxd'),
                  join(pari_module_path, 'auto_gen.pxi')]
